"""config Module"""

import json
import os
import shutil

class Config():
    """Config class"""
    def __init__(self, config_file) -> None:
        self.config_file = config_file
        self.config = None

        try:
            with open(self.config_file, "r", encoding="UTF-8") as handle:
                self.config = json.load(handle)
        except FileNotFoundError:
            os.makedirs(os.path.dirname(self.config_file), exist_ok=True)
            shutil.copyfile("hochbeet/config.json", self.config_file)
            with open(self.config_file, "r", encoding="UTF-8") as handle:
                self.config = json.load(handle)


    def hostinfo(self):
        """Deliver hostinfo"""
        res = self.config["hostname"], int(self.config["port"])
        return res


    def get_water_autostate(self, ident: int):
        """Return water auto state of entry belonging to ident"""
        for entry in self.config['water']:
            if int(entry['id']) == ident:
                return entry['autostate']
        return None


    def get_water_times(self, ident: int):
        """Return water times of entry belonging to ident"""
        for entry in self.config['water']:
            if int(entry['id']) == ident:
                return entry['times']
        return None


    def set_water_autostate(self, ident: str):
        """Set water auto state of entry belonging to ident"""
        for idx in range(len(self.config['water'])):
            if self.config['water'][idx]['id'] == ident:
                self.config['water'][idx]['autostate'] = True
                with open(self.config_file, "w", encoding="UTF-8") as handle:
                    json.dump(self.config, handle)
                return


    def clear_water_autostate(self, ident: str):
        """Clear water auto state of entry belonging to ident"""
        for idx in range(len(self.config['water'])):
            if self.config['water'][idx]['id'] == ident:
                self.config['water'][idx]['autostate'] = False
                with open(self.config_file, "w", encoding="UTF-8") as handle:
                    json.dump(self.config, handle)
                return


    def set_water_times(self, ident: str, times):
        """Set water times of entry belonging to ident"""
        for idx in range(len(self.config['water'])):
            if self.config['water'][idx]['id'] == ident:
                self.config['water'][idx]['times'] = times
                with open(self.config_file, "w", encoding="UTF-8") as handle:
                    json.dump(self.config, handle)
                return
