"""Remote module"""

import logging

from xmlrpc.server import SimpleXMLRPCServer
from . import config, control


class RemoteControl():
    """RemoteControl"""
    def __init__(self, configfile):
        self.log = logging.getLogger()
        self.config = config.Config(configfile)

        host = (self.config.hostinfo())
        self.server = SimpleXMLRPCServer(host, allow_none=True)
        self.control = control.Control(configfile)

        self.server.register_function(self.set_water_autostate, 'set_water_autostate')
        self.server.register_function(self.clear_water_autostate, 'clear_water_autostate')
        self.server.register_function(self.set_water_times, 'set_water_times')

        self.server.register_function(self.config.get_water_autostate, 'get_water_autostate')
        self.server.register_function(self.config.get_water_times, 'get_water_times')

        self.server.register_function(self.control.set_water_state, 'set_water_state')
        self.server.register_function(self.control.clear_water_state, 'clear_water_state')

    def set_water_times(self, ident: str, times):
        """Set water times"""
        self.config.set_water_times(ident, times)
        self.control.reload_config()

    def set_water_autostate(self, ident: str):
        """Set water auto state"""
        self.config.set_water_autostate(ident)
        self.control.reload_config()

    def clear_water_autostate(self, ident: str):
        """Clear water auto state"""
        self.config.clear_water_autostate(ident)
        self.control.reload_config()


    def start(self):
        """Start remote server"""
        self.log.info('Control-c to quit')
        self.control.start()
        self.server.serve_forever()

        self.log.info("Shutting down...")
        self.control.stop()
        self.log.info("...done. Exiting...")
